@@ -17,7 +17,8 @@ package Dist::Zilla::PluginBundle::CJM;
 # ABSTRACT: Build a distribution like CJM
 #---------------------------------------------------------------------
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
+# This file is part of Dist-Zilla-PluginBundle-CJM 0.02 (March 7, 2010)
 
 use Moose;
 #use Moose::Autobox;
@@ -40,14 +41,17 @@ Dist::Zilla::PluginBundle::CJM - Build a distribution like CJM
 
 =head1 VERSION
 
-This document describes version 0.01 of
-Dist::Zilla::PluginBundle::CJM, released October 11, 2009
-as part of Dist-Zilla-PluginBundle-CJM version 0.01.
+This document describes version 0.02 of
+Dist::Zilla::PluginBundle::CJM, released March 7, 2010
+as part of Dist-Zilla-PluginBundle-CJM version 0.02.
 
 =head1 DESCRIPTION
 
 This is a placeholder while I figure out how to best use Dist::Zilla.
 
+=for Pod::Coverage
+bundle_config
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Dist::Zilla::PluginBundle::CJM requires no configuration files or environment variables.
@@ -62,10 +66,10 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  S<< C<< <perl AT cjmweb.net> >> >>
+Christopher J. Madsen  C<< <perlATcjmweb.net> >>
 
 Please report any bugs or feature requests to
-S<< C<< <bug-Dist-Zilla-PluginBundle-CJM AT rt.cpan.org> >> >>,
+C<< <bug-Dist-Zilla-PluginBundle-CJMATrt.cpan.org> >>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-PluginBundle-CJM>
 
@@ -74,7 +78,7 @@ L<< http://github.com/madsen/dist-zilla-pluginbundle-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Christopher J. Madsen.
+This software is copyright (c) 2010 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
